summaryrefslogtreecommitdiffstats
path: root/quanta/src/quanta_init.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <[email protected]>2011-12-21 14:24:43 -0600
committerSlávek Banko <[email protected]>2012-06-19 19:42:58 +0200
commit44b195a5922fe83a0769b971e8805cd2d3b5450e (patch)
tree5c21414324c577cd4b13a13b51a0c37a57d6cd1b /quanta/src/quanta_init.cpp
parent39356ff58b6a5a76b0ee7fa85c538598ededdeff (diff)
downloadtdewebdev-44b195a5922fe83a0769b971e8805cd2d3b5450e.tar.gz
tdewebdev-44b195a5922fe83a0769b971e8805cd2d3b5450e.zip
Rename obsolete tq methods to standard names
(cherry picked from commit b0f531735b0175ba112ceb87d01731a7b2334772)
Diffstat (limited to 'quanta/src/quanta_init.cpp')
-rw-r--r--quanta/src/quanta_init.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/quanta/src/quanta_init.cpp b/quanta/src/quanta_init.cpp
index 3d79323e..83260d8f 100644
--- a/quanta/src/quanta_init.cpp
+++ b/quanta/src/quanta_init.cpp
@@ -191,13 +191,13 @@ void QuantaInit::initQuanta()
m_quanta->m_problemsOutputView = addToolTreeView(m_quanta->m_problemOutput, i18n("Problems"), SmallIcon("info"), KDockWidget::DockBottom);
m_quanta->m_annotationOutputView = addToolTreeView(m_quanta->m_annotationOutput, i18n("Annotations"), SmallIcon("stamp"), KDockWidget::DockBottom);
// Restore the dock tqlayout
m_config->setGroup ("General Options");
- TQString tqlayout = m_config->readEntry("Window tqlayout", "Default");
+ TQString layout = m_config->readEntry("Window layout", "Default");
int mdiMode = m_config->readNumEntry("MDI mode", -1);
- if (mdiMode != -1 && tqlayout != "Default")
+ if (mdiMode != -1 && layout != "Default")
{
- m_quanta->readDockConfig(m_config); //FIXME: This causes the visible widget construction on startup, but is needed to restore the window tqlayout...
+ m_quanta->readDockConfig(m_config); //FIXME: This causes the visible widget construction on startup, but is needed to restore the window layout...
if (mdiMode != KMdi::IDEAlMode)
m_quanta->setToolviewStyle(qConfig.toolviewTabs);
}
@@ -301,7 +301,7 @@ void QuantaInit::initQuanta()
continue;
int length = s.find(";)") - begin + 1;
TQString s2 = s.mid(begin, length - 1);
- replacementMap[s[0].tqunicode()] = s2;
+ replacementMap[s[0].unicode()] = s2;
}
file.close();
}
@@ -191,13 +191,13 @@ void QuantaInit::initQuanta()
m_quanta->m_problemsOutputView = addToolTreeView(m_quanta->m_problemOutput, i18n("Problems"), SmallIcon("info"), KDockWidget::DockBottom);
m_quanta->m_annotationOutputView = addToolTreeView(m_quanta->m_annotationOutput, i18n("Annotations"), SmallIcon("stamp"), KDockWidget::DockBottom);
- // Restore the dock tqlayout
+ // Restore the dock layout
m_config->setGroup ("General Options");